@@ -25,7 +25,7 @@ use strict;
 use warnings;
 no warnings;
 
-our $VERSION = '2.126_01';
+our $VERSION = '2.127_01';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -95,6 +95,24 @@ C<ConfigReader::Simple> to get these values:
 
 =over 4
 
+=item cpan_user
+
+Your PAUSE user id.
+
+=item cpan_pass
+
+Your PAUSE password, but don't use this. Put it in the environment
+variable.
+
+=item http_proxy
+
+=item https_proxy
+
+=item ignore_prereqs
+
+A whitespace separated list of modules for C<Test::Prereq> to ignore.
+But, don't use C<Test::Prereq>. It was not a good idea.
+
 =item makefile_PL
 
 The name of the file to run as F<Makefile.PL>.  The default is
@@ -111,19 +129,10 @@ The name of the file created by C<makefile_PL> above.  The default is
 C<"Makefile">, but you can set it to C<"Build"> for
 C<Module::Build>-based systems.
 
-=item cpan_user
+=item module_name
 
-Your PAUSE user id.
-
-=item cpan_pass
-
-=item http_proxy
-
-=item https_proxy
-
-=item ignore_prereqs
-
-A whitespace separated list of modules for C<Test::Prereq> to ignore.
+C<release> tries to guess the module name from the distro name, but if
+you don't like that, set the module name in the config file.
 
 =back
 
@@ -202,7 +211,7 @@ sub _set_defaults {
 			quiet          => 0,
 			devnull        => File::Spec->devnull,
 			ignore_prereqs => '',
-
+			module_name    => undef,
 			%params,
 		   };
 
@@ -255,6 +264,7 @@ sub _process_configuration {
 		[ qw(Makefile.PL makefile_PL) ],
 		[ qw(Makefile    makefile)    ],
 		[ qw(make        make)        ],
+		[ qw(module_name module_name) ],
 		);
 
 	foreach my $pair ( @pairs ) {
@@ -265,7 +275,6 @@ sub _process_configuration {
 		}
 	}
 
-
 	my @required = qw(  );
 
 	my $ok = 1;
@@ -277,7 +286,6 @@ sub _process_configuration {
 		}
 	$self->_die( "Missing configuration data" ) unless $ok;
 
-
 	if( $self->config->perls ) {
 		my @paths = split /:/, $self->config->perls;
 
@@ -790,7 +798,7 @@ name if not set on the command line.
 
 sub dist {
 	my $self = shift;
-	$self->_print( "Making dist... " );
+	$self->_print( "Making dist...\n" );
 
 	$self->build_makefile;
 
@@ -815,7 +823,7 @@ sub dist {
 	$self->_die( "Local file '$self->{local_file}' does not exist\n" )
 		unless -f $self->local_file;
 
-	$self->_print( "done\n" );
+	$self->_print( "Done making dist\n" );
 	}
 
 =item disttest
@@ -945,8 +953,6 @@ sub dist_version {
 		$self->_debug( "Unhandled version" );
 		return '';
 		}
-
-
 	}
 
 =item dist_version_format
@@ -965,6 +971,27 @@ sub dist_version_format {
 	sprintf "%s.%s%s", $major, $minor, $dev;
 	}
 
+=item module_name
+
+Returns the module name. This either takes it from the config file
+or tries to guess it from the distro name.
+
+=cut
+
+sub module_name {
+	my $self = shift;
+	return $self->{module_name} if $self->{module_name};
+
+	my $name = $self->local_file;
+	$self->_debug( "Guessing name. Local file is  <$name>\n" );
+
+	$name =~ s/-\d.*//g;
+	$name =~ s/-/::/g;
+	$self->_debug( "Guessing name. Module name is  <$name>\n" );
+
+	$self->{module_name} = $name;
+	}
+
 =item check_manifest
 
 Run `make manifest` and report anything it finds. If it gives output,
